Module substrate_manager

Module substrate_manager 

Substrate manager — manages per-substrate convergence DAGs.

Each operational substrate (financial, compute, network, etc.) has its own convergence DAG. The substrate manager composes them into a single ConvergenceGraph and computes per-substrate convergence distances.

Structs

SubstrateManager
Manages multiple substrate-scoped convergence DAGs and composes them into a unified convergence graph.