Module nats

Module nats 

NATS event bus for tatara — inter-task communication, log aggregation, and catalog change notifications.

Optional: if NATS is not configured, all publish operations are no-ops. Uses JetStream for guaranteed delivery of critical operations and core NATS for ephemeral data (logs, metrics).

Structs

NatsConfig
Configuration for the NATS event bus.
NatsEventBus
NATS event bus for publishing events, logs, and catalog changes.