pub struct SuiClient { /* private fields */ }Expand description
Client for the sui daemon REST API.
Implementations
Sourceimpl SuiClient
impl SuiClient
Sourcepub fn new(daemon_addr: &str) -> Self
pub fn new(daemon_addr: &str) -> Self
Create a new sui client pointing at the given daemon address.
Sourcepub async fn build(
&self,
flake_ref: &str,
system: Option<&str>,
extra_args: Vec<String>,
) -> Result<String>
pub async fn build( &self, flake_ref: &str, system: Option<&str>, extra_args: Vec<String>, ) -> Result<String>
Build a derivation via sui-daemon.
Sourcepub async fn eval_json(&self, expr: &str) -> Result<Value>
pub async fn eval_json(&self, expr: &str) -> Result<Value>
Evaluate a Nix expression via sui-daemon.
Sourcepub async fn push_to_cache(
&self,
store_path: &str,
cache_name: Option<&str>,
) -> Result<()>
pub async fn push_to_cache( &self, store_path: &str, cache_name: Option<&str>, ) -> Result<()>
Push a store path to the binary cache via sui-daemon.
Sourcepub async fn health_check(&self) -> bool
pub async fn health_check(&self) -> bool
Check if the sui-daemon is reachable.